@@ -8,7 +8,7 @@
 
 #define HOME_DIR g_get_home_dir()
 
-HD_DEFINE_PLUGIN_MODULE (CountdownPlugin, countdown_plugin,      HD_TYPE_HOME_PLUGIN_ITEM)
+HD_DEFINE_PLUGIN_MODULE (CountdownPlugin, countdown_plugin, HD_TYPE_HOME_PLUGIN_ITEM)
 
 gboolean update_content (CountdownPlugin *desktop_plugin);
 
@@ -319,8 +319,8 @@ void modifyCountdown_clicked (GtkButton *button, CountdownPlugin *desktop_plugin
         gchar *printDate, *printTime, *compTime;
 		GtkTreeIter iter;
 
-        hildon_date_button_get_date (HILDON_DATE_BUTTON (dateButton), &year, &month, &day);
-        hildon_time_button_get_time (HILDON_TIME_BUTTON (timeButton), &hours, &minutes);
+        hildon_date_selector_get_date (HILDON_DATE_SELECTOR (dateSelector), &year, &month, &day);
+        hildon_time_selector_get_time (HILDON_TIME_SELECTOR (timeSelector), &hours, &minutes);
 
         printDate = g_strdup_printf ("%02d/%02d/%02d",year,month+1,day);
         printTime = g_strdup_printf ("%02d:%02d", hours, minutes);
@@ -789,6 +789,8 @@ gboolean update_content (CountdownPlugin *desktop_plugin)
 	
 	g_date_free (startDate);
 	g_date_free (endDate);
+	
+	gtk_widget_set_size_request (GTK_WIDGET (desktop_plugin), -1, -1);
 
 	return TRUE;
 }
@@ -816,20 +818,30 @@ countdown_plugin_check_desktop (GObject *gobject, GParamSpec *pspec, CountdownPl
 	}
 }
 
+/*static void countdown_size_request (GtkWidget *widget, GtkRequisition *requisition)
+{
+	g_warning ("countdown_size_request");
+	GTK_WIDGET_CLASS (countdown_plugin_parent_class)->size_request (widget, requisition);
+}*/
+
 /*static void
 countdown_plugin_realize (GtkWidget *widget)
 {
-	GdkScreen *screen;
+	g_warning ("countdown_plugin_realize");
+  GdkScreen *screen = gtk_widget_get_screen (widget);
+  GdkColormap *colormap = gdk_screen_get_rgba_colormap (screen);
 
-	screen = gtk_widget_get_screen (widget);
-	gtk_widget_set_colormap (widget,
-				   gdk_screen_get_rgba_colormap (screen));
+	  if (colormap)
+	  {
+		  g_warning ("colormap");
+		  gtk_widget_set_colormap (widget, colormap);
+		  gtk_widget_set_default_colormap (colormap);
+	  }
+	  g_warning ("made it past gtk_widget_set_colormap");
 
-	gtk_widget_set_app_paintable (widget,
-						TRUE);
+  gtk_widget_set_app_paintable (widget, TRUE);
 
-	GTK_WIDGET_CLASS(g_type_class_peek_parent
-				 (GTK_FRAME_GET_CLASS(widget)))->realize(widget);
+  GTK_WIDGET_CLASS (countdown_plugin_parent_class)->realize (widget);
 }*/
 
 /*static gboolean
@@ -840,23 +852,19 @@ countdown_plugin_expose_event (GtkWidget *widget, GdkEventExpose *event)
 	
 	if (GTK_WIDGET_DRAWABLE(widget) == FALSE){
 		return FALSE;
-	}*/
+	}
 
-    /* Create cairo context */
-    /*cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
+    cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
     gdk_cairo_region (cr, event->region);
-    cairo_clip (cr);*/
+    cairo_clip (cr);
 
-    /* Draw alpha background */
-    /*cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+    cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
     cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.0);
-    cairo_paint (cr);*/
+    cairo_paint (cr);
 
-    /* Free context */
-    /*cairo_destroy (cr);
+    cairo_destroy (cr);
 	
-	return GTK_WIDGET_CLASS(g_type_class_peek_parent
-                         (GTK_FRAME_GET_CLASS(widget)))->expose_event(widget, event);
+	return GTK_WIDGET_CLASS(countdown_plugin_parent_class)->expose_event(widget, event);
 }*/
 
 static void
@@ -895,10 +903,11 @@ static void
 countdown_plugin_class_init (CountdownPluginClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  //GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   object_class->finalize = countdown_plugin_finalize;
  
+  //widget_class->size_request = countdown_size_request;
   //widget_class->realize = countdown_plugin_realize;
   //widget_class->expose_event = countdown_plugin_expose_event;
 }
@@ -908,3 +917,9 @@ countdown_plugin_class_finalize (CountdownPluginClass *class) {
 	//g_warning ("countdown_plugin_class_finalize");
 	
 } 
+
+CountdownPlugin*
+countdown_plugin_new (void)
+{
+  return g_object_new (COUNTDOWN_TYPE_PLUGIN, NULL);
+}
